@@ -1,6 +1,6 @@
 see.geo.tck<-function () 
 {
-require(tcltk) || stop("tcltk support is absent")
+
     if (!exists("slider.env")) 
   slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
 
@@ -25,7 +25,7 @@ require(tcltk) || stop("tcltk support is absent")
                     }
     tclServiceMode(TRUE)
     m <- tktoplevel()
-    tkwm.title(m, "Visualizing the Geometric Distribution")
+    tkwm.title(m, "GEO(\u03C0)")
     tkpack(tklabel(m,text="      Visualizing the Geometric Distribution      "))
     tkwm.geometry(m, "+0+0")
     
@@ -56,7 +56,7 @@ require(tcltk) || stop("tcltk support is absent")
  
 see.geocdf.tck<-function () 
 {
-require(tcltk) || stop("tcltk support is absent")
+
     if (!exists("slider.env")) 
     slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
 
@@ -68,7 +68,7 @@ require(tcltk) || stop("tcltk support is absent")
     assign("xmax", tclVar(xmax), envir = slider.env)
     
        
-   dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE)) 
+   dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.5,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE)) 
    norm.refresh <- function(...) {
         p <- as.numeric(evalq(tclvalue(p), envir = slider.env))
         xmin <- as.numeric(evalq(tclvalue(xmin), envir = slider.env))
@@ -88,7 +88,7 @@ require(tcltk) || stop("tcltk support is absent")
                     }
     tclServiceMode(TRUE)
     m <- tktoplevel()
-    tkwm.title(m, "Visualizing the Geometric Distribution")
+    tkwm.title(m, "GEO(\u03C0)")
     tkpack(tklabel(m,text="      Visualizing the Geometric Distribution      "))
     tkwm.geometry(m, "+0+0")
     
